Presentation enum

Inheritance
Available extensions

Values

FULLSCREEN → const Presentation
DIALOG_CENTER → const Presentation
DIALOG_TOP_FILL → const Presentation
DIALOG_TOP_START → const Presentation
DIALOG_TOP_END → const Presentation
DIALOG_TOP_CENTER → const Presentation
DIALOG_BOTTOM_FILL → const Presentation
DIALOG_BOTTOM_START → const Presentation
DIALOG_BOTTOM_END → const Presentation
DIALOG_BOTTOM_CENTER → const Presentation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateEntry(bool value) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

animateExit(bool value) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

cornerRadius(int radius) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

dimAmount(double amount) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

dimBackground(bool value) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

dismissOnBackPress(bool value) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

dismissOnTouchOutside(bool value) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

marginAll(int margin) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

marginHorizontal(int margin) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

marginVertical(int margin) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPurchaseSecondaryAction(PurchaseSecondaryAction action) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

setShufflePinPad(bool shuffle) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

sizePercent(double percent) PresentationConfig

Available on Presentation, provided by the PresentationModifiers extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Presentation>
A constant List of the values in this enum, in order of their declaration.