Invoice class
Invoice details for BNPL checkout.
Constructors
Properties
- extraDiscount → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lineItems
→ List<
InvoiceLineItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingCharges → double
-
final
- total → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited