InvoiceLineItem class

Line item in BNPL invoice.

Constructors

InvoiceLineItem({required String sku, required String description, required double unitCost, required double quantity, required double netTotal, double discountAmount = 0, double taxTotal = 0, required double total})
const

Properties

description String
final
discountAmount double
final
hashCode int
The hash code for this object.
no setterinherited
netTotal double
final
quantity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String
final
taxTotal double
final
total double
final
unitCost double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited