InvoiceRefundRequest class

Invoice request. Mirrors native InvoiceRefundRequest,InvoicePaymentRequest class.

Constructors

InvoiceRefundRequest({required PaymentMethod paymentMethod, required double amount, required String transactionId})
const

Properties

amount double
final
hashCode int
The hash code for this object.
no setterinherited
paymentMethod PaymentMethod
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited