InvoicePaymentResponse class

BNPL checkout response. Mirrors native Bnpl class.

Constructors

InvoicePaymentResponse({required String checkoutId, required String paymentGatewayTransactionId, required String checkoutDeeplink, required String transactionId})
const
InvoicePaymentResponse.fromMap(Map<String, dynamic> map)
factory

Properties

final
checkoutId String
final
hashCode int
The hash code for this object.
no setterinherited
paymentGatewayTransactionId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited