Pagination class

Pagination parameters. Matches: Pagination in native SDK.

Constructors

Pagination({int pageNumber = 0, int pageSize = 50, SortOrder sortOrder = SortOrder.DESCENDING, SortField sortBy = SortField.CREATED})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pageNumber int
final
pageSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy SortField
final
sortOrder SortOrder
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited