PresentationConfig class

Chainable presentation configuration. Matches: Presentation.DIALOG_BOTTOM_FILL.cornerRadius(16)... in native SDK.

Constructors

PresentationConfig(Presentation presentation)

Properties

hashCode int
The hash code for this object.
no setterinherited
presentation Presentation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateEntry(bool value) PresentationConfig
animateExit(bool value) PresentationConfig
cornerRadius(int radius) PresentationConfig
dimAmount(double amount) PresentationConfig
dimBackground(bool value) PresentationConfig
dismissOnBackPress(bool value) PresentationConfig
dismissOnTouchOutside(bool value) PresentationConfig
marginAll(int margin) PresentationConfig
marginHorizontal(int margin) PresentationConfig
marginVertical(int margin) PresentationConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPurchaseSecondaryAction(PurchaseSecondaryAction action) PresentationConfig
setShufflePinPad({bool shuffle = true}) PresentationConfig
sizePercent(double percent) PresentationConfig
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited