SdkTheme class

Chainable theme builder. Access via EdfaPayPlugin.theme(). Matches: SdkTheme in native SDK.

Constructors

SdkTheme.create()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFontScale(double scale) SdkTheme
setHeaderImage(String base64) SdkTheme
setPoweredByImage(String base64) SdkTheme
setPresentation(dynamic presentation) SdkTheme
Accepts Presentation enum or chained presentation (e.g., Presentation.DIALOG_CENTER.cornerRadius(20))
setPrimaryColor(String color) SdkTheme
setPurchaseCelebrationAnimation(String? lottieJsonBase64, {double speed = 1.0}) SdkTheme
setRegisterCelebrationAnimation(String? lottieJsonBase64, {double speed = 1.0}) SdkTheme
setSecondaryColor(String color) SdkTheme
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited