Terminal class

Terminal available for binding. Mirrors native Terminal class.

Constructors

Terminal({required String terminalId, required String trsm, required String providerTid})
const
Terminal.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
providerTid String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalId String
final
trsm String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited