TerminalBindingTask class

Task for binding a terminal. Mirrors native TerminalBindingTask.

When binding completes (success or error), the original callbacks from initiate() are triggered automatically.

Constructors

TerminalBindingTask.fromList(List<Map<String, dynamic>> terminalMaps, EdfaPayBridge bridge)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminals List<Terminal>
final

Methods

bind({Terminal? terminal}) Future<void>
Show native terminal selection UI. On completion, initiate()'s onSuccess or onError will be called.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited