Transaction class

Lightweight transaction reference used for reverse/void/capture/refund. Matches: Transaction.withRRN(...) / Transaction.withTxnNumber(...) in native SDK.

Constructors

Transaction.withRRN(String rrn, DateTime? txnDate, {TransactionType? type})
Create a transaction reference using RRN (for refund, capture, reversal).
factory
Transaction.withTxnNumber(String txnNumber, DateTime? txnDate, {TransactionType? type})
Create a transaction reference using transaction number.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rrn String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txnDate DateTime?
final
txnNumber String?
final
type TransactionType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
yyyyMMdd(DateTime? date) String

Operators

operator ==(Object other) bool
The equality operator.
inherited