UserInfo class

User information returned by Extension.getUserInfo(). Mirrors native UserInfo class.

Constructors

UserInfo({required int id, required String userId, required String username, required String businessUnitId, required String keyHash, required bool status, required bool deleted, required String role, required int createdAt, int? updatedAt})
const
UserInfo.fromMap(Map<String, dynamic> map)
factory

Properties

businessUnitId String
final
createdAt int
final
deleted bool
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
keyHash String
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool
final
updatedAt int?
final
userId String
final
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited