Presentation class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animateEntry(
bool animate) → Presentation -
animateExit(
bool animate) → Presentation -
cornerRadius(
int radius) → Presentation -
dimAmount(
double amount) → Presentation -
dimBackground(
bool dim) → Presentation -
dismissOnBackPress(
bool dismiss) → Presentation -
dismissOnTouchOutside(
bool dismiss) → Presentation -
marginAll(
int margin) → Presentation -
marginHorizontal(
int margin) → Presentation -
marginVertical(
int margin) → Presentation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setPurchaseSecondaryAction(
PurchaseSecondaryAction action) → Presentation -
setShufflePinPad(
{bool random = true}) → Presentation -
sizePercent(
double percent) → Presentation -
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- DIALOG_BOTTOM_CENTER → Presentation
-
final
- DIALOG_BOTTOM_END → Presentation
-
final
- DIALOG_BOTTOM_FILL → Presentation
-
final
- DIALOG_BOTTOM_START → Presentation
-
final
- DIALOG_CENTER → Presentation
-
final
- DIALOG_TOP_CENTER → Presentation
-
final
- DIALOG_TOP_END → Presentation
-
final
- DIALOG_TOP_FILL → Presentation
-
final
- DIALOG_TOP_START → Presentation
-
final
- FULLSCREEN → Presentation
-
final