InvoicePaymentRequest class
Constructors
- InvoicePaymentRequest({required PaymentMethod? paymentMethod, required String merchantId, required double amount, required String currency, required String phoneNumber, required String email, required String orderReferenceId, required String orderNumber, String locale = 'en_US', String paymentType = 'PAY_BY_INSTALMENTS', required Invoice invoice, required AdditionalData additionalData})
-
const
Properties
- additionalData → AdditionalData
-
final
- amount → double
-
final
- currency → String
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoice → Invoice
-
final
- locale → String
-
final
- merchantId → String
-
final
- orderNumber → String
-
final
- orderReferenceId → String
-
final
- paymentMethod → PaymentMethod?
-
final
- paymentType → String
-
final
- phoneNumber → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited